@@ -30,12 +30,12 @@ def test_opt_in():
     page = project.get_page('render_this_one')
     assert page.title == "Render (by name)"
     assert page.is_markdown_rendered()
-    assert page.find(page.meta.signal), f"Did not find signal '{page.meta.signal}'"
+    assert page.find_text(page.meta.signal), f"Did not find signal '{page.meta.signal}'"
 
     print([page.source.markdown for page in project.pages.values()])
     page2 = project.get_page('rendered/noname')
     assert page2.file.src_uri == 'rendered/noname.md', f"is: {page2.file.src_uri}"
-    assert page2.find("0: Hello world")
+    assert page2.find_text("0: Hello world")
     assert page2.is_markdown_rendered()
 
 
@@ -45,4 +45,4 @@ def test_opt_in():
     exception_page = project.get_page('rendered/exception')
     assert exception_page.meta.render_macros == False
     assert not exception_page.is_markdown_rendered()
-    assert exception_page.find('macros_info')
+    assert exception_page.find_text('macros_info')
